<?php
# Plugin: PrivateBlog
# Allows you to make a blog private, i.e. so that it can only be accessed
# by certain users.  You can set both a list of allowed users and a list of 
# allowed groups.  If a user is not logged in or is not in the allowed list,
# then all articles, entries, and comments will be hidden and all pages will be 
# redirected to the login page.
#
# Note that this only provides real security if you turn off the RSS plugins.  
# The RSS feeds generated by the standard plugins are static XML files, so PHP 
# cannot keep users from accessing them.  Obviously, if people can just read the RSS feeds, then the
# blog isn't *really* private.

class PrivateBlog extends Plugin {
	function PrivateBlog() {
		$this->plugin_desc = _("Makes a blog private so that only certain users can access it.");
		$this->plugin_version = "0.2.0";
		$this->addOption("userlist", _("Allowed user names (comma separated)"), "");
		$this->addOption("grouplist", _("Allowed group names (comma separated)"), "");
		$this->getConfig();
	}

	function check_allow() {
		
		global $SYSTEM;
		$blog = NewBlog();
		$usr = NewUser();
		$ret  = false;
		
		if ($usr->checkLogin()) {
		
			$users = explode(",", $this->userlist);
			for($i=0; $i<count($users); $i++) $users[$i] = trim($users[$i]);
			$groups = explode(",", $this->grouplist);
			for($i=0; $i<count($groups); $i++) $groups[$i] = trim($groups[$i]);
		
			$ret = $SYSTEM->canModify($blog, $usr);
			
			if (! $ret) $ret = in_array($usr->username(), $users);
			
			if (! $ret) {
				foreach ($groups as $grp) {
					if ($SYSTEM->inGroup($usr->username(), $grp)) {
						$ret = true;
						echo $grp;
						break;
					}
				}
			}
		}
		return $ret;
	}
	
	function do_redir(&$param) {
		$blog = NewBlog();
		if (! $blog->isBlog()) return false;
		if (current_file() == "login.php" || 
		    current_file() == "logout.php") {
				return false;
		}
		if (! $this->check_allow()) $param->redirect($blog->uri('login'));
	}
	
	function kill_entry(&$ent) {
		global $PAGE;
		if (! $this->check_allow($PAGE)) {
			$ent->data = '';
			$ent->subject = '';
		}
	}
}

$plug = new PrivateBlog();
$plug->registerEventHandler("page", "OnOutput", "do_redir");
$plug->registerEventHandler("blogentry", "InitComplete", "kill_entry");
$plug->registerEventHandler("article", "InitComplete", "kill_entry");
$plug->registerEventHandler("blogcomment", "InitComplete", "kill_entry");
?>
